================================
Review Board 2.5.4 Release Notes
================================

**Release date**: April 13, 2016


New Features
============

* Added a field on the settings page for configuring the static media URL.

  This is useful if offloading the static media to a CDN or another
  dedicated server.

* Added information on the support level and status of any active support
  contracts in the administration dashboard.

* Added logging of access attempts on Local Sites when the requesting user
  doesn't have access. (:bug:`3108`)

  This helps with security audits on sites partitioned using Local Sites.

  Patch by Minh Le Hoang.

* Added logging of access attempts on the API when the requesting user
  doesn't have access. (:bug:`3108`)


Usability Improvements
======================

* Improved the styling of the mobile menu.

  The menu no longer contains indentation for items in a section, providing
  more room and consistency. There's also less wasted space above the first
  section.

* Individual bug IDs in the dashboard no longer wrap, making it easier to
  read bug IDs on certain types of trackers. (:bug:`4376`)


Extensions
==========

* Added compatibility with extensions packages as Python Wheels.

* Added support for extension-provided JavaScript unit tests.

  Extensions can now declare JavaScript unit test files in a ``"tests"``
  bundle. These tests will run automatically when accessing
  ``http://<server>/js-tests/extensions/`` on a development server.

  JSExtension classes aren't initialized automatically on this page. Test
  suites are responsible for initializing them if needed.

* The :py:data:`~rb2.5:reviewboard.reviews.signals.review_request_closed`
  signal now sends the closed description and whether it's in rich text.


Web API
=======

* :ref:`rb2.5:webapi2.0-web-hook-list-resource` now allows or creating
  webhooks without repositories.


Bug Fixes
=========

Diff Viewer
-----------

* Fixed filenames on interdiffs when the filenames have been renamed multiple
  times. (:bug:`4156`)

  If a file has been renamed more than once between a set of revisions, the
  filenames shown in the diff viewer would be incorrect. This has been changed
  to better represent the correct names.

  Patch by Adriano Arce.

* Fixed the display of tooltips for the diff complexity icons.

  Patch by Griffin Myers.

* Fixed the Reply link for existing comments in the comment dialog.
  (:bug:`4049`).

  Depending on the comment, the link would sometimes point nowhere, making
  this far less than useful.

  Patch by Israel Madueme.


Review Requests
---------------

* Users configured as default reviewers are no longer added to review requests
  if they've been marked as inactive.

  Patch by Griffin Myers.

* Deleting file attachments that haven't been made public no longer keeps
  the files around in storage. (:bug:`4054`)

  Patch by Weijie Sun.


New Review Request Page
-----------------------

* Fixed a regression in selecting the default branch for the list of commits.


User Page
---------

* Fixed links to the lists of user's review requests and reviews when
  on a Local Site.


Git
---

* Fixed stale caches for file lookups after changing the Raw File URL mask
  for a repository. (:bug:`4051`)

  Patch by Kevin Chiu.


Perforce
--------

* Added compatibility with stunnel_ version 4 for Perforce.

  stunnel is used for securely sending traffic to another Perforce server.
  We've had support for stunnel version 3, which didn't work with version 4.

  We've added support for working with both version 3 and version 4. This
  shouldn't require any changes to existing setups.

* Fixed infinite loops attempting to find an unused port when using stunnel
  on MacOS X.


.. _stunnel: https://www.stunnel.org/


Subversion
----------

* Fixed Unicode errors with non-ASCII passwords on Subversion servers.
  (:bug:`4369`)

  Patch by Jim Hagan.

* Fixed fetching contents from Subversion repositories configured on
  Beanstalk_.


.. _Beanstalk: http://beanstalkapp.com/


Webhooks
--------

* Fixed configuring webhooks with multiple events or no events.


Administration
--------------

* Fixed auto-updating the static media and uploaded media paths when changing
  the location of a site directory.


Contributors
============

* Adriano Arce
* Barret Rennie
* Christian Hammond
* David Trowbridge
* Griffin Myers
* Israel Madueme
* Jim Hagan
* Kevin Chiu
* Minh Le Hoang
* Weijie Sun
